@@ -12,6 +12,7 @@ from .cover_page_ams import create_cover_page
 from .cover_page_project import create_project_cover
 from .directory import get_images
 from .mv import create_mv_folder
+from .functions import get_client_and_project, get_date, get_project_number
 
 font_dir = Path('X:/9999_BID_AMS/AMS-VFB_Fonts')
 
@@ -63,7 +64,7 @@ def main():
     pdf.set_subject(project_name)
     pdf.set_title(f"Briefing - {project_name}")
 
-    proj_number = str(project_path)[3:7]
+    proj_number = get_project_number(project_path)
 
     if len(proj_number) != 4:
         click.secho('probber')
@@ -77,7 +78,7 @@ def main():
         pdf.cell(w=50, h=10, txt=project_name.upper(), align='R', ln=2)
         pdf.set_font('Arial', size=14)
         pdf.cell(w=50, h=10, txt=camname, align='R')
-        pdf.image(logo, x=9, y=190, w=65)
+        pdf.image(logo, x=9, y=190, w=65, link="https://www.animotions.be")
         pdf.set_fill_color(200, 200, 200)
         pdf.rect(x=80, y=15, w=frame_width, h=frame_height, style='F')
         width, height = imagesize.get(str(f))
@@ -88,10 +89,9 @@ def main():
 
         pdf.image(str(f), x=80, y=15+(frame_height - ratio_y)/2, w=200)
 
-    #mv = project_path.joinpath('MV')
-
     mv_dir = create_mv_folder(project_path, verbose=True)
 
-    dest = mv_dir.joinpath('pov_brief.pdf')
+    dest = mv_dir.joinpath(
+        f'{get_date()}_{get_client_and_project(project_path)}_briefing.pdf')
     pdf.output(dest, 'F')
     webbrowser.open(dest)
